@@ -8,6 +8,7 @@ from composer.algorithms.augmix import AugMixHparams
 from composer.algorithms.blurpool import BlurPoolHparams
 from composer.algorithms.channels_last import ChannelsLastHparams
 from composer.algorithms.colout import ColOutHparams
+from composer.algorithms.cutmix import CutMixHparams
 from composer.algorithms.cutout import CutOutHparams
 from composer.algorithms.dummy import DummyHparams
 from composer.algorithms.ghost_batchnorm import GhostBatchNormHparams
@@ -31,6 +32,7 @@ registry: Dict[str, Type[AlgorithmHparams]] = {
     'blurpool': BlurPoolHparams,
     'channels_last': ChannelsLastHparams,
     'seq_length_warmup': SeqLengthWarmupHparams,
+    'cutmix': CutMixHparams,
     'cutout': CutOutHparams,
     'ghost_batchnorm': GhostBatchNormHparams,
     'label_smoothing': LabelSmoothingHparams,
