@@ -8,7 +8,7 @@ from composer.algorithms.augmix.augmix import augment_and_mix as augment_and_mix
 _name = 'AugMix'
 _class_name = 'AugMix'
 _functional = 'augment_and_mix'
-_tldr = ''
+_tldr = 'Image-perserving data augmentations'
 _attribution = '(Hendrycks et al, 2020)'
 _link = 'http://arxiv.org/abs/1912.02781'
 _method_card = ''
