@@ -229,6 +229,10 @@ class SelectiveBackprop(Algorithm):
 
         with state.precision_context(state.precision):
             new_input, new_target = selective_backprop(
-                input, target, model, loss, self.hparams.keep,
-                self.hparams.scale_factor)  # type: ignore - ditto because of loss
+                input,
+                target,
+                model,  # type: ignore - ditto because of loss
+                loss,
+                self.hparams.keep,
+                self.hparams.scale_factor)
         state.batch = (new_input, new_target)
