@@ -15,18 +15,19 @@ log = logging.getLogger(__name__)
 
 @dataclass
 class SWAHparams(AlgorithmHparams):
+    """See :class:`~composer.algorithms.swa.SWA`"""
 
     swa_start: float = hp.optional(
-        doc='Percentage of epochs before starting to apply SWA. Default 0.8.',
+        doc='Percentage of epochs before starting to apply SWA.',
         default=0.8,
     )
     anneal_epochs: int = hp.optional(
-        doc='Number of annealing epochs. Default 10.',
+        doc='Number of annealing epochs.',
         default=10,
     )
     swa_lr: Optional[float] = hp.optional(
         doc='The final learning rate to anneal towards with this scheduler. '
-        'Set to None for no annealing. Default: None',
+        'Set to None for no annealing.',
         default=None,
     )
 
