@@ -10,7 +10,7 @@ from types import MethodType
 from typing import TYPE_CHECKING, Any, Callable
 
 from composer.core.serializable import Serializable
-from composer.utils.ddp import is_rank_set, is_rank_zero
+from composer.utils.ddp import is_rank_zero
 
 if TYPE_CHECKING:
     from composer import Logger, State
@@ -20,21 +20,21 @@ class Callback(Serializable, abc.ABC):
     """Base class for callbacks.
     
     A callback is similar to an
-    :class:`~composer.core.algorithm.Algorithm`, in that
+    :class:`Algorithm`, in that
     they are run on specific events. By convention, Callbacks should not
-    modify :class:`~composer.core.state.State`.
+    modify :class:`State`.
 
-    Each method name corresponds to an :class:`~composer.core.event.Event`.
+    Each method name corresponds to an :class:`Event`.
 
     Subclasses of callbacks should override these methods to run in response
-    to given :class:`~composer.core.event.Event` invocations.
+    to given :class:`Event` invocations.
     """
 
     def __init__(self) -> None:
         super().__init__()
 
     def init(self, state: State, logger: Logger) -> None:
-        """Called on the :attr:`~composer.core.event.Event.INIT` event.
+        """Called on the :attr:`~Event.INIT` event.
 
         Args:
             state (State): The global state.
@@ -45,7 +45,7 @@ class Callback(Serializable, abc.ABC):
         pass
 
     def training_start(self, state: State, logger: Logger) -> None:
-        """Called on the :attr:`~composer.core.event.Event.TRAINING_START` event.
+        """Called on the :attr:`Event.TRAINING_START` event.
 
         Args:
             state (State): The global state.
@@ -56,7 +56,7 @@ class Callback(Serializable, abc.ABC):
         pass
 
     def epoch_start(self, state: State, logger: Logger) -> None:
-        """Called on the :attr:`~composer.core.event.Event.EPOCH_START` event.
+        """Called on the :attr:`~Event.EPOCH_START` event.
 
         Args:
             state (State): The global state.
@@ -67,7 +67,7 @@ class Callback(Serializable, abc.ABC):
         pass
 
     def batch_start(self, state: State, logger: Logger) -> None:
-        """Called on the :attr:`~composer.core.event.Event.BATCH_START` event.
+        """Called on the :attr:`~Event.BATCH_START` event.
 
         Args:
             state (State): The global state.
@@ -78,7 +78,7 @@ class Callback(Serializable, abc.ABC):
         pass
 
     def after_dataloader(self, state: State, logger: Logger) -> None:
-        """Called on the :attr:`~composer.core.event.Event.AFTER_DATALOADER` event.
+        """Called on the :attr:`~Event.AFTER_DATALOADER` event.
 
         Args:
             state (State): The global state.
@@ -89,7 +89,7 @@ class Callback(Serializable, abc.ABC):
         pass
 
     def before_train_batch(self, state: State, logger: Logger) -> None:
-        """Called on the :attr:`~composer.core.event.Event.BEFORE_TRAIN_BATCH` event.
+        """Called on the :attr:`~Event.BEFORE_TRAIN_BATCH` event.
 
         Args:
             state (State): The global state.
@@ -100,7 +100,7 @@ class Callback(Serializable, abc.ABC):
         pass
 
     def before_forward(self, state: State, logger: Logger) -> None:
-        """Called on the :attr:`~composer.core.event.Event.BEFORE_FORWARD` event.
+        """Called on the :attr:`~Event.BEFORE_FORWARD` event.
 
         Args:
             state (State): The global state.
@@ -111,7 +111,7 @@ class Callback(Serializable, abc.ABC):
         pass
 
     def after_forward(self, state: State, logger: Logger) -> None:
-        """Called on the :attr:`~composer.core.event.Event.AFTER_FORWARD` event.
+        """Called on the :attr:`~Event.AFTER_FORWARD` event.
 
         Args:
             state (State): The global state.
@@ -122,7 +122,7 @@ class Callback(Serializable, abc.ABC):
         pass
 
     def before_loss(self, state: State, logger: Logger) -> None:
-        """Called on the :attr:`~composer.core.event.Event.BEFORE_LOSS` event.
+        """Called on the :attr:`~Event.BEFORE_LOSS` event.
 
         Args:
             state (State): The global state.
@@ -133,7 +133,7 @@ class Callback(Serializable, abc.ABC):
         pass
 
     def after_loss(self, state: State, logger: Logger) -> None:
-        """Called on the :attr:`~composer.core.event.Event.AFTER_LOSS` event.
+        """Called on the :attr:`~Event.AFTER_LOSS` event.
 
         Args:
             state (State): The global state.
@@ -144,7 +144,7 @@ class Callback(Serializable, abc.ABC):
         pass
 
     def before_backward(self, state: State, logger: Logger) -> None:
-        """Called on the :attr:`~composer.core.event.Event.BEFORE_BACKWARD` event.
+        """Called on the :attr:`~Event.BEFORE_BACKWARD` event.
 
         Args:
             state (State): The global state.
@@ -155,7 +155,7 @@ class Callback(Serializable, abc.ABC):
         pass
 
     def after_backward(self, state: State, logger: Logger) -> None:
-        """Called on the :attr:`~composer.core.event.Event.AFTER_BACKWARD` event.
+        """Called on the :attr:`~Event.AFTER_BACKWARD` event.
 
         Args:
             state (State): The global state.
@@ -166,7 +166,7 @@ class Callback(Serializable, abc.ABC):
         pass
 
     def after_train_batch(self, state: State, logger: Logger) -> None:
-        """Called on the :attr:`~composer.core.event.Event.AFTER_TRAIN_BATCH` event.
+        """Called on the :attr:`~Event.AFTER_TRAIN_BATCH` event.
 
         Args:
             state (State): The global state.
@@ -177,7 +177,7 @@ class Callback(Serializable, abc.ABC):
         pass
 
     def batch_end(self, state: State, logger: Logger) -> None:
-        """Called on the :attr:`~composer.core.event.Event.BATCH_END` event.
+        """Called on the :attr:`~Event.BATCH_END` event.
 
         Args:
             state (State): The global state.
@@ -188,7 +188,7 @@ class Callback(Serializable, abc.ABC):
         pass
 
     def epoch_end(self, state: State, logger: Logger) -> None:
-        """Called on the :attr:`~composer.core.event.Event.EPOCH_END` event.
+        """Called on the :attr:`~Event.EPOCH_END` event.
 
         Args:
             state (State): The global state.
@@ -199,7 +199,7 @@ class Callback(Serializable, abc.ABC):
         pass
 
     def training_end(self, state: State, logger: Logger) -> None:
-        """Called on the :attr:`~composer.core.event.Event.TRAINING_END` event.
+        """Called on the :attr:`~Event.TRAINING_END` event.
 
         Args:
             state (State): The global state.
@@ -210,7 +210,7 @@ class Callback(Serializable, abc.ABC):
         pass
 
     def eval_start(self, state: State, logger: Logger) -> None:
-        """Called on the :attr:`~composer.core.event.Event.EVAL_START` event.
+        """Called on the :attr:`~Event.EVAL_START` event.
 
         Args:
             state (State): The global state.
@@ -221,7 +221,7 @@ class Callback(Serializable, abc.ABC):
         pass
 
     def eval_batch_start(self, state: State, logger: Logger) -> None:
-        """Called on the :attr:`~composer.core.event.Event.EVAL_BATCH_START` event.
+        """Called on the :attr:`~Event.EVAL_BATCH_START` event.
 
         Args:
             state (State): The global state.
@@ -232,7 +232,7 @@ class Callback(Serializable, abc.ABC):
         pass
 
     def eval_before_forward(self, state: State, logger: Logger) -> None:
-        """Called on the :attr:`~composer.core.event.Event.EVAL_BATCH_FORWARD` event.
+        """Called on the :attr:`~Event.EVAL_BATCH_FORWARD` event.
 
         Args:
             state (State): The global state.
@@ -243,7 +243,7 @@ class Callback(Serializable, abc.ABC):
         pass
 
     def eval_after_forward(self, state: State, logger: Logger) -> None:
-        """Called on the :attr:`~composer.core.event.Event.EVAL_AFTER_FORWARD` event.
+        """Called on the :attr:`~Event.EVAL_AFTER_FORWARD` event.
 
         Args:
             state (State): The global state.
@@ -254,7 +254,7 @@ class Callback(Serializable, abc.ABC):
         pass
 
     def eval_batch_end(self, state: State, logger: Logger) -> None:
-        """Called on the :attr:`~composer.core.event.Event.EVAL_BATCH_END` event.
+        """Called on the :attr:`~Event.EVAL_BATCH_END` event.
 
         Args:
             state (State): The global state.
@@ -265,7 +265,7 @@ class Callback(Serializable, abc.ABC):
         pass
 
     def eval_end(self, state: State, logger: Logger) -> None:
-        """Called on the :attr:`~composer.core.event.Event.EVAL_END` event.
+        """Called on the :attr:`~Event.EVAL_END` event.
 
         Args:
             state (State): The global state.
@@ -303,9 +303,8 @@ class RankZeroCallback(Callback, abc.ABC):
                 original_fn: Callable[[State, Logger], None] = original_fn,
                 **kwargs: Any,
             ) -> None:
-                if is_rank_set():
-                    if not is_rank_zero():
-                        return
+                if not is_rank_zero():
+                    return
                 return original_fn(*args, **kwargs)
 
             setattr(self, fn_name, MethodType(wrapped_fn, self))
