@@ -7,6 +7,7 @@ from composer.models.classify_mnist import MnistClassifierHparams as MnistClassi
 from composer.models.efficientnetb0 import EfficientNetB0 as EfficientNetB0
 from composer.models.efficientnetb0 import EfficientNetB0Hparams as EfficientNetB0Hparams
 from composer.models.gpt2 import GPT2Hparams as GPT2Hparams
+from composer.models.gpt2 import GPT2Model as GPT2Model
 from composer.models.model_hparams import Initializer as Initializer
 from composer.models.model_hparams import ModelHparams as ModelHparams
 from composer.models.resnet18 import ResNet18 as ResNet18
@@ -18,4 +19,5 @@ from composer.models.resnet56_cifar10 import CIFARResNetHparams as CIFARResNetHp
 from composer.models.resnet101 import ResNet101 as ResNet101
 from composer.models.resnet101 import ResNet101Hparams as ResNet101Hparams
 from composer.models.transformer_shared import MosaicTransformer as MosaicTransformer
+from composer.models.unet import UNet as UNet
 from composer.models.unet import UnetHparams as UnetHparams
