@@ -9,4 +9,4 @@ _name = 'ResNet18'
 _quality = ''
 _metric = 'Top-1 Accuracy'
 _ttt = '?'
-_hparams = 'hparams.yaml'
+_hparams = 'resnet18.yaml'
